import React from 'react'
import { Button, Card, Form, Radio, Input, Select } from 'antd'
import { formItemLayout } from '../utils'

const Item = Form.Item

const BuildingTypeDetail = (props) => {
  const { buildingType, form } = props
  const { getFieldDecorator } = form

  return (
    <Card size="small" title={buildingType?.buildingTypeName} extra={<Button type="link" icon="close" />}>
      <Form>
        <Item label="价格类型" {...formItemLayout}>
          {getFieldDecorator('priceType')(
            <Radio.Group>
              <Radio value="average">均价</Radio>
              <Radio value="total">总价</Radio>
              <Radio value="lease">租赁价</Radio>
            </Radio.Group>
          )}
        </Item>
        <Item label="价格区间" help='最高价与最低价一致时，只展示一个' {...formItemLayout}>
          <span>{getFieldDecorator('startPrice')(<Input type="number" placeholder="最低价" style={{width: '120px'}} maxLength="9" />)}</span>
          <span>-</span>
          <span>{getFieldDecorator('endPrice')(<Input type="number" placeholder="最高价" style={{width: '120px'}} maxLength="9" />)}</span>
          {/* <span>{this.props.type.priceType === "average" ? "元/㎡" : this.props.type.priceType === "lease" ? "元/㎡/天" : "万元/套"}</span> */}
        </Item>
        <Item label="销售状态" {...formItemLayout}>
          {getFieldDecorator('marketStatus')(
            <Select placeholder="销售状态">
              <Option value="待售">待售</Option>
              <Option value="在售">在售</Option>
              <Option value="售罄">售罄</Option>
              <Option value="在租">在租</Option>
            </Select>,
          )}
        </Item>
        <Item label="装修标准" {...formItemLayout}>
          {getFieldDecorator('decoration')(<Input />)}
        </Item>
        <Item label="产权年限" {...formItemLayout}>
          {getFieldDecorator('rightsYear')(<Input />)}
        </Item>
      </Form>
    </Card>
  )
}

export default Form.create()(BuildingTypeDetail)
